.. pymnash documentation master file, created by
   sphinx-quickstart on Wed Dec 13 14:29:27 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pymnash's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Usage <usage>
   Sample Games <sample_games>
   Game Methods <game_methods>
   Utilities <utilities>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
